( cd usr/bin ; rm -rf awk )
( cd usr/bin ; ln -sf  gawk awk )
( cd usr/bin ; rm -rf bash )
( cd usr/bin ; ln -sf  /bin/bash bash )
( cd usr/bin ; rm -rf vi )
( cd usr/bin ; ln -sf  elvis vi )
( cd usr/bin ; rm -rf view )
( cd usr/bin ; ln -sf  elvis view )
( cd usr/bin ; rm -rf install )
( cd usr/bin ; ln -sf  ginstall install )
( cd usr/bin ; rm -rf uncompress )
( cd usr/bin ; ln -sf  compress uncompress )
( cd usr/bin ; rm -rf batch )
( cd usr/bin ; ln -sf  at batch )
( cd usr/bin ; rm -rf atq )
( cd usr/bin ; ln -sf  at atq )
( cd usr/bin ; rm -rf atrm )
( cd usr/bin ; ln -sf  at atrm )
( cd usr/bin ; rm -rf input )
( cd usr/bin ; ln -sf  elvis input )
( cd usr/bin ; rm -rf ex )
( cd usr/bin ; ln -sf  elvis ex )
( cd usr/man/preformat/cat1 ; rm -rf atq.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf  at.1.gz atq.1.gz )
( cd usr/man/preformat/cat1 ; rm -rf batch.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf  at.1.gz batch.1.gz )
( cd usr/man/preformat/cat1 ; rm -rf atrm.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf  at.1.gz atrm.1.gz )
( cd bin ; rm -rf compress )
( cd bin ; ln -sf  /usr/bin/compress compress )
